#
# spec file for package ubi_reader
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2018-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           ubi_reader
Version:        0.8.12
Release:        1.1
Summary:        Extract files from UBI and UBIFS images
License:        LGPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://github.com/onekey-sec/ubi_reader
Source:         https://github.com/onekey-sec/ubi_reader/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%description
Collection of Python scripts for reading information about and extracting
data from UBI and UBIFS images.

The following tools are included:
 - ubireader_display_info:
   Show information about UBI or UBIFS image.
 - ubireader_extract_files:
   Extract contents of a UBI or UBIFS image.
 - ubireader_extract_images:
   Extract UBI or UBIFS images from file containing UBI data in it.
 - ubireader_list_files:
   List and Extract files of a UBI or UBIFS image.
 - ubireader_utils_info:
   Determine settings for recreating UBI image.

%prep
%autosetup -n ubi_reader-%{version}
chmod -x README.md
find ubireader -name "*.py" | xargs sed -i -e '/^#!\//, 1d'

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python3_sitelib}

%files
%license LICENSE
%doc README.md
%{_bindir}/ubireader_display_blocks
%{_bindir}/ubireader_display_info
%{_bindir}/ubireader_extract_files
%{_bindir}/ubireader_extract_images
%{_bindir}/ubireader_utils_info
%{_bindir}/ubireader_list_files
%{python3_sitelib}/ubi*

%changelog
* Wed Jun 18 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.12
  * Fix for KeyError in decrypt_filenames #110
- Update to version 0.8.11
  * Add UBIFS decryption support (fscrypt) #108
* Tue Feb 11 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.10
  * Add close() and context management to ubi_file.
  * read_block_data: use data_size for static volumes.
  * parse the 'hash' field after 'key' in IDX:branch block.
- Update to version 0.8.9
  * Fix LZO decompression after switching to lzallright.
- Update to version 0.8.8
  * chore(poetry): bump lzallright version.
- Update to version 0.8.7
  * Fix faulty package name in requirements.
  * deps: replace python-lzo by lzallright.
  * Move to poetry.
  * fix pyproject package definition.
  * fix(scripts): adapt scripts so we can expose them thru poetry.
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.5:
  * fix path traversal vulnerability
  * Ignore block align, let fail if data actually is missing
  * fix old block crc check
  * python 3.x related cleanups
* Thu Apr 28 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  * Fixed: Handling of 0x00 blocks at start of file.
* Mon Jan 17 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.2
  * Improved performance
* Mon Jan  3 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.7.1
  * Bug fixes and minor updates.
* Tue Mar  2 2021 Martin Hauke <mardnh@gmx.de>
- Package cleanup
* Thu Aug 13 2020 Martin Hauke <mardnh@gmx.de>
- Rename package python-ubi_reader -> ubi_reader
- Update to version 0.6.3
  * Added ubireader_list_files script
* Sat Sep  8 2018 mardnh@gmx.de
- Initial package, version 0.6.0
